"""
Django settings for textbin app.

Generated by 'django-admin startproject' using Django 1.8.4.

For more information on this file, see
https://docs.djangoproject.com/en/1.8/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.8/ref/settings/
"""
# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
import sys

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


sys.path.insert(0, os.path.dirname(BASE_DIR))

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.8/howto/media-files/
STATIC_URL = os.environ.get('TEXTBIN_STATIC_URL', '/static/')

_PATH = os.path.abspath(os.path.dirname(__file__))
STATIC_ROOT = os.environ.get('TEXTBIN_STATIC_ROOT',
                             os.path.join(_PATH, 'files', 'static'))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.8/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = os.environ.get('TEXTBIN_SECRET_KEY',
                            'rz_e@sj*9-&va!qaz7$=+vq)ej8=mext*4uprhcpe#3q_xr=d#')

# SECURITY WARNING: don't run with debug turned on in production!

# Debug=False only if TEXTBIN_DEBUG defined as 'False'
DEBUG = os.environ.get('TEXTBIN_DEBUG', 'True').capitalize()
if DEBUG == 'False':
    DEBUG = False
else:
    DEBUG = True

if 'TEXTBIN_ALLOWED_HOSTS' in os.environ:
    ALLOWED_HOSTS = [os.environ.get('TEXTBIN_ALLOWED_HOSTS')]
else:
    ALLOWED_HOSTS = []


APPEND_SLASH = True

# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'textbin',
    'rest_framework',
    'bootstrap3',
    'snowpenguin.django.recaptcha2',
)

# CAPTCHA KEYS
if DEBUG:
    # With the default test keys, you will always get No CAPTCHA and all verification requests will pass.
    RECAPTCHA_PUBLIC_KEY = "6LeIxAcTAAAAAJcZVRqyHh71UMIEGNQ_MXjiZKhI"
    RECAPTCHA_PRIVATE_KEY = "6LeIxAcTAAAAAGG-vFI1TnRWxMZNFuojJ4WifJWe"
else:
    # Try to get keys from environment
    RECAPTCHA_PUBLIC_KEY = os.environ.get('TEXTBIN_RECAPTCHA_PUBLIC_KEY',
                                          "6LeIxAcTAAAAAJcZVRqyHh71UMIEGNQ_MXjiZKhI")
    RECAPTCHA_PRIVATE_KEY = os.environ.get('TEXTBIN_RECAPTCHA_PRIVATE_KEY',
                                           "6LeIxAcTAAAAAGG-vFI1TnRWxMZNFuojJ4WifJWe")

# link with static bs3 files
BOOTSTRAP3 = {
    'include_jquery': False,
    'jquery_url': STATIC_URL + 'textbin/js/jquery-1.12.0.min.js',
    'base_url': STATIC_URL + 'textbin/',
    'css_url': STATIC_URL + 'textbin/css/bootstrap.min.css',
    'theme_url': STATIC_URL + 'textbin/css/bootstrap-theme.min.css',
    'javascript_url': STATIC_URL + 'textbin/js/bootstrap.min.js',
}

REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': [],
    # 'DEFAULT_PERMISSION_CLASSES': [],
    'DEFAULT_PERMISSION_CLASSES': (
                    # set API to be accessible to any user
                    'rest_framework.permissions.AllowAny',
                ),
    'PAGE_SIZE': 10,  # to turn on pagination
}

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
)

ROOT_URLCONF = 'textbin.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'textbin.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.8/ref/settings/#databases

if 'TEXTBIN_DATABASE_ENGINE' in os.environ:
    DATABASES = {
        'default': {
            'ENGINE': os.environ['TEXTBIN_DATABASE_ENGINE'],
            'NAME': os.environ['TEXTBIN_DATABASE_NAME'],
            'USER': os.environ['TEXTBIN_DATABASE_USER'],
            'PASSWORD': os.environ['TEXTBIN_DATABASE_PASSWORD'],
            'HOST': os.environ['TEXTBIN_DATABASE_HOST'],
            'ATOMIC_REQUESTS': True,
        }
    }
else:
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.sqlite3',
            'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
        }
    }


# Internationalization
# https://docs.djangoproject.com/en/1.8/topics/i18n/

LANGUAGE_CODE = 'ru'

TIME_ZONE = 'Europe/Moscow'

USE_I18N = True

USE_L10N = True

USE_TZ = True



# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-02-02 10:29
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import textbin.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Media',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.SmallIntegerField(choices=[(1, 'Image'), (2, 'Video')])),
                ('url', models.URLField(max_length=2000, validators=[textbin.models.valid_url_media])),
            ],
        ),
        migrations.CreateModel(
            name='Text',
            fields=[
                ('id', models.CharField(default=textbin.models._unique_id, editable=False, max_length=10, primary_key=True, serialize=False)),
                ('text', models.TextField(blank=True, default='')),
                ('posted_at', models.DateTimeField(auto_now_add=True)),
                ('author_name', models.CharField(blank=True, default='Anonymous', max_length=100)),
                ('author_url', models.URLField(blank=True, default='')),
            ],
        ),
        migrations.AddField(
            model_name='media',
            name='text',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='media', to='textbin.Text', verbose_name='Attached to'),
        ),
    ]



# -*- coding: utf-8 -*-
# Django
from django.conf.urls import include, url
from django.contrib import admin
# For Django REST api
from rest_framework.urlpatterns import format_suffix_patterns
# Textbin
from . import views


urlpatterns = [
    # Django REST Framework: API
    # --------------------------

    # .../api/posts/
    url(r'^api/$', views.ApiTextCreate.as_view(),
        name='text_api_create'),

    # .../textbin/api/12b29374
    # .../textbin/api/12b29374.api  or *.json
    url(r'^api/(?P<pk>\w+)$', views.ApiTextDetail.as_view(),
        name='text_api_detail'),

    # For authentication
    # url(r'^api-auth/', include('rest_framework.urls', namespace='rest')),
    ]

# Allow to specify data format as api/12b29374.api or *.json
urlpatterns = format_suffix_patterns(urlpatterns)

urlpatterns += [
    url(r'^admin/', include(admin.site.urls)),
    # Create post
    # -----------
    # .../
    url(r'^$', views.TextCreate.as_view(), name='text_create'),
    # View post details
    # -----------------
    # (!) place it last.
    # All unknown urls will be interpreted as post id's (exclude admin and api)
    # .../12b29374
    url(r'^(?!admin|api)(?P<pk>\w+)$', views.TextDetail.as_view(), name='text_detail'),
    ]



from __future__ import print_function, division, absolute_import, unicode_literals

from django.contrib import admin
from django.template.defaultfilters import truncatechars

from . import models

# from utils.decorator import attrs
# ToDo: find utils package!


def attrs(**kwargs):
    def attrsetter(function):
        for key, value in kwargs.items():
            setattr(function, key, value)
        return function
    return attrsetter


class ImageInline(admin.StackedInline):
    model = models.Media
    extra = 1


@admin.register(models.Text)
class TextAdmin(admin.ModelAdmin):
    list_display = ('id', 'author_name', 'text_truncated')
    search_fields = ('id',)
    inlines = [ImageInline,]
    readonly_fields = ('id', )

    @staticmethod
    @attrs(short_description='text', admin_order_field='text')
    def text_truncated(obj):
        return truncatechars(obj.text, 140)


@admin.register(models.Media)
class MediaAdmin(admin.ModelAdmin):
    list_display = ('id', 'type', 'text')
    readonly_fields = ('id',)
    search_fields = ('id',)



# -*- coding: utf-8 -*-
from __future__ import print_function, division, absolute_import, unicode_literals
from rest_framework import serializers
from .models import Text, Media


class TextSerializer(serializers.ModelSerializer):
    class Meta:
        model = Text

    # Attached medias urls
    media = serializers.ListField(
        child=serializers.URLField(required=True),
        required=False)

    def create(self, validated_data):
        """
        Create a new `Text` instance and it`s attached 'Media'
        instances, given the validated data, return new 'Text' instance
        """
        # Get media's urls
        urls = validated_data.pop('media', [])
        # Create Text instance
        new_text = Text(**validated_data)

        # Additional check: user must input text or add media url(s)
        if not (urls or new_text.text):
            raise serializers.ValidationError(
                "You must enter text or add media url(s)")
        else:
            new_text.save()

        # Create Media instances
        for url in urls:
            Media.objects.create_media(url=url, text=new_text)
        return new_text

    def to_representation(self, obj):
        """ Return details for `Text` instance and it`s attached `Media`
        """
        # Add Text data
        text = {'id':          obj.id,
                'author_name': obj.author_name,
                'author_url':  obj.author_url,
                'posted_at':   obj.posted_at,
                'text':        obj.text}
        # Create attached media's urls list
        urls = list()
        medias = obj.media.all()
        for media in medias:
            urls.append(media.url)
        text['media'] = urls
        return text



# -*- coding: utf-8 -*-
from __future__ import print_function, division, absolute_import, unicode_literals
import os

from django.test import TestCase
from django.core.urlresolvers import reverse

from rest_framework.test import APITestCase
from rest_framework import status

from .models import Text

# disable the recaptcha field and let test works
os.environ['RECAPTCHA_DISABLE'] = 'True'


class UrlsTestCase(APITestCase):
    """ Тесты доступа к URL по имени протсранства имён и именам URL
    """
    msg = "Message in the test post"   # message in Text instance`s .text field
    text = None                        # Text instance

    @classmethod
    def setUpClass(cls):
        """ Создание тестового поста
        """
        super(UrlsTestCase, cls).setUpClass()
        cls.text = Text.objects.create(text=cls.msg)

    def check_response_status(self, url, status):
        """ вспомогательная функция
        """
        response = self.client.get(url)
        self.assertEqual(response.status_code, status)

    def test_get_url_text_create(self):
        """ Форма создания поста
        """
        self.check_response_status(
            reverse('text_create'),
            status.HTTP_200_OK)

    def test_get_url_text_api_create(self):
        """ Открывается как запрос GET, который запрещён (запрос всех постов)
        Статус должен быть - 405
        """
        self.check_response_status(
            reverse('text_api_create'),
            status.HTTP_405_METHOD_NOT_ALLOWED)

    def test_get_url_text_detail(self):
        url = 'text_detail'
        response = self.client.get(reverse(url,
                                           args=(self.text,)))
        self.assertTrue(self.msg.encode() in response.content)
        self.assertEqual(response.status_code, status.HTTP_200_OK)


class ApiTextCreate(APITestCase):
    """
    Тесты REST API - создание поста
    """
    def test_api_text_create_only_text(self):
        """ Содание поста POST-запросом по url REST API
        Заполняются  поля `текст` и `автор`
        """
        msg = 'API-test: creating text'
        author = 'UnitTest'
        url = reverse('text_api_create')
        response = self.client.post(url, {"text": msg,
                                          "author_name": author})
        self.assertEqual(response.status_code, status.HTTP_201_CREATED)

    def test_api_text_create_only_url(self):
        """ Содание поста POST-запросом по url REST API
        Заполняется только поле `media` - прикрепляется изображение.
        Автор - по умолчанию - Anonymous
        """
        media = 'http://s.smmplanner.com/favicon.ico'
        url = reverse('text_api_create')
        response = self.client.post(url, {"media": [media, ], })
        self.assertEqual(response.status_code, status.HTTP_201_CREATED)

    def test_api_text_create_no_content(self):
        """ Содание поста POST-запросом по url REST API
        Указывается только имя автора. Такие посты запрещены как пустые.
        """
        author = 'UnitTest'
        url = reverse('text_api_create')
        response = self.client.post(url, {"author_name": author})
        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)

    def test_api_text_detail(self):
        """ Получение поста GET-запросом по url REST API
        """
        msg = 'API-test: fetching text'
        obj = Text.objects.create(text=msg)
        url = reverse('text_api_detail', args=(obj,))
        response = self.client.get(url)
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        self.assertTrue(msg.encode() in response.content)


class TextDetailTests(TestCase):
    """
    Тесты проверяющие отображение запрашиваемого поста

    Проверка выполняется по содержимому получаемой страницы в той или иной
    ситуации.
    """
    def test_detail_view(self):
        """ Запрос по id поста
        Создаётся пост с текстом. Запрашивается представление поста.
        Результат должен содержать текст поста
        """
        msg = 'Test-post created!'
        new_text = Text.objects.create(text=msg)
        response = self.client.get(reverse('text_detail',
                                           args=(new_text,)))
        self.assertTrue(msg.encode() in response.content)

    def test_detail_view_with_nonexist_text(self):
        """ Запрос по id поста который несуществует
        Результатотм такого запроса должна быть страница со статусом 404
        """
        response = self.client.get(reverse('text_detail',
                                           args=('abcdefgh',)))
        self.assertEqual(response.status_code, 404)



# -*- coding: utf-8 -*-
from __future__ import print_function, division, absolute_import, unicode_literals

from django.forms import ModelForm, forms
from django.forms.models import inlineformset_factory

from snowpenguin.django.recaptcha2.fields import ReCaptchaField
from snowpenguin.django.recaptcha2.widgets import ReCaptchaWidget
# from captcha.fields import ReCaptchaField

from .models import Text, Media


class TextForm(ModelForm):
    def __init__(self, *args, **kwargs):
        super(TextForm, self).__init__(*args, **kwargs)
        # Установка widget label, placeholder
        for field_name in self.fields:
            placeholder = Text.widget_placeholders[field_name]
            label = Text.widget_labels[field_name]
            self.fields[field_name].widget.attrs['placeholder'] = placeholder
            self.fields[field_name].label = label

    class Meta:
        model = Text
        fields = ['author_name', 'author_url', 'text']
        # exclude = ['id', 'posted_at']


class MediaInline(ModelForm):
    class Meta:
        model = Media
        fields = ['url']


MediaFormSet = inlineformset_factory(Text,
                                     Media,
                                     form=MediaInline,
                                     extra=1,
                                     can_delete=False,
                                     can_order=False)


class CaptchaForm(forms.Form):
    captcha = ReCaptchaField(widget=ReCaptchaWidget())
    # captcha = ReCaptchaField(attrs={'theme': 'clean'})



# -*- coding: utf-8 -*-
from __future__ import print_function, division, absolute_import, unicode_literals
import six
import random
import string
import urllib
from collections import defaultdict

from django.db import models
from django.core.exceptions import ObjectDoesNotExist, FieldError
from django.utils.encoding import python_2_unicode_compatible
from django.core.exceptions import ValidationError

# Length of unique hex-key for every text
ID_LENGTH = 10


def _unique_id():
    """ Returns unique ID for Text.id """
    check_field = 'id'
    model = Text
    new_id = None
    while True:
        new_id = ''.join(random.choice(
            string.ascii_letters + string.digits) for _ in range(ID_LENGTH))
        try:
            model.objects.get(**{check_field: new_id})
        except ObjectDoesNotExist as err:
            # ID is unique
            break
    return new_id


class MediaType(object):
    IMAGE = 1
    VIDEO = 2
    CHOICES = (
        (IMAGE, 'Image'),
        (VIDEO, 'Video'),
    )

    @classmethod
    def autodetect(cls, url):
        if not url:
            raise ValueError('Unable to autodetect media type: url is False.')
        res = urllib.urlopen(url)
        http_message = res.info()
        # full = http_message.type    # 'text/plain'
        curr_type = http_message.maintype  # 'text'
        curr_type = curr_type.capitalize()
        for choise in cls.CHOICES:
            if curr_type == choise[1]:
                return choise[0]
        # If content type not in cls.CHOICES
        raise FieldError('Not supported content type at ' + url)


def valid_url_media(url):
    try:
        MediaType.autodetect(url)
    except FieldError:
        raise ValidationError('URL must point to one of this: %s'
                              % ', '.join([ch[1] for ch in MediaType.CHOICES]))


@python_2_unicode_compatible
class Text(models.Model):
    len_author = 100  # max length of author_name CharField
    def_author = 'Anonymous'  # Default author name

    id = models.CharField(max_length=ID_LENGTH, primary_key=True,
                          # default=objects.unique_id,
                          default=_unique_id,
                          editable=False)
    text = models.TextField(default='',
                            blank=True)

    posted_at = models.DateTimeField(auto_now_add=True)
    author_name = models.CharField(max_length=len_author,
                                   default=def_author,
                                   blank=True)
    author_url = models.URLField(blank=True,
                                 default='')

    # Параметры отображения в форме
    widget_labels = dict()
    widget_labels['text'] = 'Текст сообщения'
    widget_labels['author_name'] = 'Ваше имя'
    widget_labels['author_url'] = 'Домашняя страница'

    widget_placeholders = defaultdict(lambda: '')
    # Не указанные в словаре поля будут иметь пустую строку placeholder
    widget_placeholders['text'] = 'Введите текст'

    @property
    def images(self):
        return self.media_set.filter(type=MediaType.IMAGE)

    @property
    def videos(self):
        return self.media_set.filter(type=MediaType.VIDEO)

    def __str__(self):
        return self.id


class MediaManager(models.Manager):
    def create_media(self, text, url, type=None):
        # Create Media instance with content type autodetection from url (if
        # not specified)
        if not type:
            type = MediaType.autodetect(url)
        media = self.create(text=text, url=url, type=type)
        return media


@python_2_unicode_compatible
class Media(models.Model):
    # Objects manager
    objects = MediaManager()

    # Objects attributes
    text = models.ForeignKey(Text,
                             editable=False,
                             verbose_name='Attached to',
                             on_delete=models.CASCADE,
                             related_name='media')
    type = models.SmallIntegerField(choices=MediaType.CHOICES)
    url = models.URLField(blank=False,
                          max_length=2000,
                          validators=[valid_url_media, ])

    def __str__(self):
        return six.text_type(self.pk)



# -*- coding: utf-8 -*-
from __future__ import print_function, division, absolute_import, unicode_literals
# Django
from django.shortcuts import render_to_response
from django.http import HttpResponseRedirect, Http404
from django.core.urlresolvers import reverse
from django.views.generic.edit import CreateView
from django.views.generic.detail import DetailView
# Django REST Framework
from .serializers import TextSerializer
from rest_framework import mixins
from rest_framework import generics
# Textbin
from .models import Text, Media, MediaType
from .forms import TextForm, MediaFormSet, CaptchaForm


class TextCreate(CreateView):
    """ View: create new `Text`-instance with attached `Media` instances
    """
    template_name = "textbin/text_create.html"
    success_url = 'text_detail'
    form_class = TextForm         # Main `Text` instance form
    formset_class = MediaFormSet  # Form of attached `Media` instances
    captcha_form = CaptchaForm    # Form for gogle reCaptcha2

    def is_form_filled(self, form):
        context = self.get_context_data(form=form)
        media_formset = context['media_formset']
        text_form = context['text_form']
        has_text = ('text' in text_form.changed_data)
        has_media = media_formset.has_changed()
        return has_text or has_media

    def get_context_data(self, **kwargs):
        context = super(TextCreate, self).get_context_data(**kwargs)
        # context = {}
        if self.request.POST:
            context['text_form'] = self.form_class(self.request.POST)
            context['media_formset'] = self.formset_class(self.request.POST)
            context['text_form'].full_clean()
            context['media_formset'].full_clean()
            context['captcha_form'] = self.captcha_form(self.request.POST)
        else:
            context['text_form'] = self.form_class()
            context['media_formset'] = self.formset_class()
            context['captcha_form'] = self.captcha_form()
        return context

    def form_valid(self, form):
        context = self.get_context_data(form=form)
        media_formset = context['media_formset']
        text_form = context['text_form']
        captcha_form = context['captcha_form']
        is_form_filled = self.is_form_filled(form)
        if is_form_filled \
                and (
                     text_form.is_valid() and
                     media_formset.is_valid() and
                     captcha_form.is_valid()
                     ):
            text_form.instance.save()
            new_text = text_form.instance
            for media_form in media_formset.forms:
                url = media_form.instance.url
                if url:
                    Media.objects.create_media(text=new_text, url=url)
            return HttpResponseRedirect(reverse(self.success_url,
                                                args=(text_form.instance.id,)))
        else:
            if not is_form_filled:
                context['error_no_content'] = \
                    "Введите текст сообщения и/или прикрепите ссылки"
            return self.render_to_response(context)

    def form_invalid(self, form):
        """
        Called if a form is invalid. Re-renders the context data with the
        data-filled forms and errors.
        """
        return self.render_to_response(
            self.get_context_data(form=form))

    def post(self, request, *args, **kwargs):
        """
        Handles POST requests, instantiating a form instance and its inline
        formsets with the passed POST variables and then checking them for
        validity.
        """
        # super(TextCreate, self).post(request, *args, **kwargs)
        self.object = None
        form_class = self.get_form_class()
        formset_class = self.formset_class
        form = self.get_form()
        # Create a formset, form instances with POST data.
        media_formset = formset_class(request.POST, prefix='media')
        text_form = form_class(request.POST)
        # If valid, save the data.
        if media_formset.is_valid() and text_form.is_valid():
            return self.form_valid(form)
        else:
            return self.form_invalid(form)


class TextDetail(DetailView):
    model = Text
    template_name = "textbin/text_detail.html"
    template_404 = "textbin/text_404.html"

    def get_context_data(self, **kwargs):
        context = super(TextDetail, self).get_context_data(**kwargs)
        text = context['text']
        # use related_name
        context['medias'] = text.media.all()
        # put to context media types
        for mtype in MediaType.CHOICES:
            context[mtype[1].lower()] = mtype[0]
        return context

    def get(self, request, *args, **kwargs):
        # ReImplemented to intercept 404
        try:
            self.object = self.get_object()
        except Http404:
            # return custom template
            return render_to_response(self.template_404, {'request': request},
                                      status=404)
        else:
            context = self.get_context_data(object=self.object)
            return self.render_to_response(context)


class ApiTextCreate(mixins.CreateModelMixin,
                    generics.GenericAPIView):
    """
    Create a new Text instance
    """
    queryset = Text.objects.all()
    serializer_class = TextSerializer

    def post(self, request, *args, **kwargs):
        return self.create(request, *args, **kwargs)


class ApiTextDetail(mixins.RetrieveModelMixin,
                    generics.GenericAPIView):
    """
    Show Text instance details
    """
    queryset = Text.objects.all()
    serializer_class = TextSerializer

    def get(self, request, *args, **kwargs):
        return self.retrieve(request, *args, **kwargs)



import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

# py_version = sys.version_info[:2]
# if not py_version == (2, 7):
#     raise RuntimeError('Requires Python version 2.7 but '
#                        ' ({}.{} detect    ed).'.format(*py_version))


setup(
    name='django-textbin',
    version='0.344',
    packages=['textbin', 'textbin.migrations'],
    url='https://github.com/zokalo/django-textbin',
    install_requires=[
        'django>=1.8.4',
        'djangorestframework>=3.3.2',
        'six>=1.5.2',
        'django-bootstrap3>=6.2.2',
        'django-recaptcha2>=0.1.7',
    ],
    include_package_data=True,  # use MANIFEST.in during install
    license='GPL v3.0',
    author='Don Dmitriy Sergeevich',
    author_email='dondmitriys@gmail.com',
    description='Django package for text sharing and exchanging',

    entry_points={
        'console_scripts': [
            'textbin = textbin.manage:main',
        ],
    },
)
